ThemeMode enum

The theme mode for survey appearance.

Inheritance
Available extensions

Values

light → const ThemeMode

Enforces light theme.

dark → const ThemeMode

Enforces dark theme.

auto → const ThemeMode

Automatically follows the system light/dark UI modes.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name String

Available on ThemeMode, provided by the ThemeModeExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ThemeMode>
A constant List of the values in this enum, in order of their declaration.