ResponseAttribute class
Represents an attribute that can be attached to a survey response.
name is the attribute name used to identify the attribute. value is the attribute value. provider is an optional provider name for the attribute.
Constructors
- ResponseAttribute.bool(String name, bool value, {String? provider})
- Creates a boolean attribute.
- ResponseAttribute.dateTime(String name, DateTime value, {String? provider})
- Creates a date time attribute.
- ResponseAttribute.num(String name, num value, {String? provider})
- Creates a number attribute.
- ResponseAttribute.string(String name, String value, {String? provider})
- Creates a string attribute.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited