SurvicateFontSystem class

Represents a complete set of fonts used by the SDK.

regular Standard font for normal body text. regularItalic Standard font with italic slant. bold Bold style font for emphasized content. boldItalic Bold style font with italic slant.

Constructors

SurvicateFontSystem({required String regular, required String regularItalic, required String bold, required String boldItalic})
const

Properties

bold String
final
boldItalic String
final
hashCode int
The hash code for this object.
no setterinherited
regular String
final
regularItalic String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited